package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!````*!\```````!``````````%BA````
M`````````$``.``(`$``%@`5``8````$````0`````````!``````````$``
M````````P`$```````#``0````````@``````````P````0``````@``````
M```"``````````(````````:`````````!H``````````0`````````!````
M!0```````````````````````````````````&B.````````:(X`````````
M``$```````$````&````F)L```````"8FP$``````)B;`0``````X`0`````
M```X%0```````````0```````@````8```"HFP```````*B;`0``````J)L!
M``````#@`0```````.`!````````"`````````!0Y71D!````(2(````````
MA(@```````"$B````````/0`````````]``````````$`````````%'E=&0&
M`````````````````````````````````````````````````````````!``
M````````4N5T9`0```"8FP```````)B;`0``````F)L!``````!H!```````
M`&@$`````````0`````````O;&EB+VQD+6UU<VPM86%R8V@V-"YS;RXQ````
M`````!$```!+````!`````@````A$!``!<`$@"@`$`6`AD"$@B$`!`D`!(F(
M@!A!N@0""$L```!,````4````%4```!6````70```%X```!?`````````&$`
M``!B`````````&,```!D````9P```````````````:\TZ&I_FGSJT^\.SMY'
M+6_%WQ\NQ9NVN(WQ#M1DU'QV5#R4(?_D#MEQ6!SZH6Q@PN4_++(!BV]"^M>'
MXD?&`5COEWF[XY)\5<,\TF>OS&:(!W#30T75[#-BV^T5C"7,?ZF<F^"G`@IJ
M&IY0O]I7&Z/@^TD``````````````````````````````````````P`'`(`9
M`````````````````````````P`2``"@`0`````````````````!````$@``
M```````````````````````)````$0````````````````````````#5`0``
M$0````````````````````````!Q`0``$@`````````````````````````0
M````$@````````````````````````"N`0``$@``````````````````````
M```8````$@`````````````````````````?````$@``````````````````
M``````#B`0``$@````````````````````````"Z`0``$@``````````````
M```````````H````(`````````````````````````#Q`@``(0``````````
M``````````````!`````$@````````````````````````!&````$@``````
M``````````````````!-````$@````````````````````````"^`@``$@``
M``````````````````````"O`@``$@````````````````````````!4````
M$@`````````````````````````(`@``$@````````````````````````!;
M````$@````````````````````````".`@``$@``````````````````````
M``!B````$@````````````````````````!J````$@``````````````````
M``````!W`@``$@````````````````````````!R````$@``````````````
M``````````!X````$@````````````````````````"!````(```````````
M``````````````"H`@``$@````````````````````````"=````$@``````
M``````````````````"B````$@````````````````````````#S`0``$0``
M``````````````````````"5`@``$@`````````````````````````U`@``
M$@````````````````````````"I````$@`````````````````````````G
M`@``$@`````````````````````````W`P``$@``````````````````````
M``#P`@``$0````````````````````````!9`@``$@``````````````````
M``````#=`@``$@````````````````````````#R`@``$0``````````````
M``````````"P````$@````````````````````````#5`@``$@``````````
M``````````````"Y````$0````````````````````````!_`0``$@``````
M``````````````````#+````(@````````````````````````#:````(```
M``````````````````````#P````$@````````````````````````"@`@``
M$@````````````````````````!%`@``$@````````````````````````#U
M````$@````````````````````````#[````(```````````````````````
M``""`@``$@`````````````````````````5`0``$@``````````````````
M``````"?`0``$@`````````````````````````:`0``$@``````````````
M``````````!G`@``$@````````````````````````".`0``$@``````````
M```````````````@`0``$@`````````````````````````Q`0``$@``````
M```````````````````#`@``$@````````````````````````!S````$@``
M```````````````````````4`@``$@````````````````````````!.`@``
M$@````````````````````````#.`@``$@`````````````````````````W
M`0``$@````````````````````````#&`@``$@``````````````````````
M``!+`0``$@````````````````````````#^`0``$@``````````````````
M``````!2`0``$@````````````````````````!9`0``$@``````````````
M``````````#O`@``(0````````````````````````!J`0``$@``````````
M```````````````W!```$``3`-"P`0````````````````#J`@``$@`)`&`=
M````````R`$```````#/`0``$@`*`!!*````````!`````````!Y`P``$@`)
M`&`M````````&`8```````!'!```$@`)`*PU````````9`````````!6`P``
M$@`)`)0G````````!`````````#K`P``$@`'`(`9````````!`````````"<
M`P``$@`)`'@S````````-`(```````#Q`P``$``3`'B@`0``````````````
M```?!```$@`)`)@G````````U`$```````#4`P``$``3`'B@`0``````````
M``````!G`P``$@`)`*PL````````M`````````"&`P``$@`)`-`E````````
M.`````````".`P``$@`)`#0L````````6`````````"R`P``$@`)``Q'````
M````<`$```````#'`P``$@`)`&PI````````(`````````#@`P``$``3`-"P
M`0````````````````!"!```$``3`-"P`0`````````````````<`P``$@`)
M`$0?````````*`````````#_`P``$@`)`(PI````````!`$```````"]`P``
M$0`2`'"@`0``````"``````````8!```$``2`'B@`0````````````````#9
M`P``$@`)`"@?``````````````````#H`P``$@`)`+!&````````7```````
M```E`P``$@`)`(PL````````(`````````!``P``$@`)`%PF````````.`$`
M```````L!```$@`)`'Q(````````E`$````````V!```$``3`-"P`0``````
M```````````+!```$@`)`)`J````````I`$`````````;W!E;F1I<@!S=&1E
M<G(`<F5A;&QO8P!A8V-E<W,`<VYP<FEN=&8`7U]D97)E9VES=&5R7V9R86UE
M7VEN9F\`;'-E96L`9V5T<&ED`'-T<F-M<`!M96US970`=6YL:6YK`&UE;6UO
M=F4`<W1R;F-M<`!L<W1A=`!C;&]S961I<@!?251-7V1E<F5G:7-T97)434-L
M;VYE5&%B;&4`;W!E;@!S=')S='(`<W1R8VAR`')E861L:6YK`%]?<W1A8VM?
M8VAK7V=U87)D`%]?8WAA7V9I;F%L:7IE`%]?<F5G:7-T97)?9G)A;65?:6YF
M;P!E>&ET`&-L;W-E`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`<F5A9`!R
M;61I<@!?7V5R<FYO7VQO8V%T:6]N`&UK9&ER`'!T:')E861?9V5T<W!E8VEF
M:6,`;65M8W!Y`'-T<FQE;@!?7W-T86-K7V-H:U]F86EL`&=E='5I9`!097)L
M7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F;W)K7VQO8VL`<&5R
M;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`
M7V9I;FD`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME
M>0!P97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E
M<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W
M6%,`<&5R;%]D97-T<G5C=`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!0
M97)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!F<')I;G1F`'-T<F1U<`!P
M=&AR96%D7V%T9F]R:P!R96%D9&ER`'-P<FEN=&8`<W1R=&]K`'-T<FYC<'D`
M7U]L:6)C7W-T87)T7VUA:6X`7U]?96YV:7)O;@!L:6)P97)L+G-O`&QI8F,N
M;75S;"UA87)C:#8T+G-O+C$`7W-T87)T7V,`9V5T7W5S97)N86UE7V9R;VU?
M9V5T<'=U:60`<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]C=7)R96YT7V5X
M96,`<&%R7W-E='5P7VQI8G!A=&@`<&%R7VUK=&UP9&ER`'AS7VEN:70`<&%R
M7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?4$%27T)/3U0`<VAA7W5P9&%T90!M
M>5]P87)?<&P`<&%R7V)A<V5N86UE`%]?8G-S7W-T87)T`%]?96YD7U\`<VAA
M7VEN:70`7U]B<W-?<W1A<G1?7P!P87)?9&ER;F%M90!P87)?:6YI=%]E;G8`
M7V5D871A`'!A<E]F:6YD<')O9P!S:&%?9FEN86P`7U]B<W-?96YD7U\`7V5N
M9`!P87)?8VQE86YU<``O=7-R+VQI8B]P97)L-2]C;W)E7W!E<FPO0T]210``
M````````F)L!```````#!````````$`@````````H)L!```````#!```````
M`.`?````````@)\!```````#!````````&`=````````F)\!```````#!```
M`````!!*````````L)\!```````#!````````(`9`````````*`!```````#
M!`````````"@`0``````$*`!```````#!````````"!*````````&*`!````
M```#!````````$M*````````**`!```````#!````````"5*````````,*`!
M```````#!````````"5+````````.*`!```````#!````````#!*````````
M0*`!```````#!````````#=+````````2*`!```````#!````````#A*````
M````6*`!```````#!````````#Q*````````8*`!```````#!````````$%*
M````````<*`!```````#!````````-9,````````B)\!```````!!```!```
M````````````D)\!```````!!```!0``````````````H)\!```````!!```
M#0``````````````J)\!```````!!```'0``````````````N)\!```````!
M!```(0``````````````P)\!```````!!```*@``````````````R)\!````
M```!!```+0``````````````T)\!```````!!```+P``````````````V)\!
M```````!!```,```````````````X)\!```````!!```-0``````````````
MZ)\!```````!!```.@``````````````\)\!```````!!```.P``````````
M````^)\!```````!!```0```````````````H)T!```````"!````P``````
M````````J)T!```````"!```!@``````````````L)T!```````"!```!P``
M````````````N)T!```````"!```"```````````````P)T!```````"!```
M"0``````````````R)T!```````"!```"@``````````````T)T!```````"
M!```"P``````````````V)T!```````"!```#```````````````X)T!````
M```"!```#0``````````````Z)T!```````"!```#P``````````````\)T!
M```````"!```$```````````````^)T!```````"!```$0``````````````
M`)X!```````"!```$@``````````````")X!```````"!```$P``````````
M````$)X!```````"!```%```````````````&)X!```````"!```%0``````
M````````()X!```````"!```%@``````````````*)X!```````"!```%P``
M````````````,)X!```````"!```&```````````````.)X!```````"!```
M&0``````````````0)X!```````"!```&@``````````````2)X!```````"
M!```&P``````````````4)X!```````"!```'```````````````6)X!````
M```"!```'@``````````````8)X!```````"!```'P``````````````:)X!
M```````"!```(```````````````<)X!```````"!```(@``````````````
M>)X!```````"!```(P``````````````@)X!```````"!```)```````````
M````B)X!```````"!```)0``````````````D)X!```````"!```)@``````
M````````F)X!```````"!```*```````````````H)X!```````"!```*0``
M````````````J)X!```````"!```*P``````````````L)X!```````"!```
M+```````````````N)X!```````"!```+@``````````````P)X!```````"
M!```+P``````````````R)X!```````"!```,```````````````T)X!````
M```"!```,0``````````````V)X!```````"!```,@``````````````X)X!
M```````"!```,P``````````````Z)X!```````"!```-```````````````
M\)X!```````"!```-@``````````````^)X!```````"!```-P``````````
M`````)\!```````"!```.```````````````")\!```````"!```.0``````
M````````$)\!```````"!```/```````````````&)\!```````"!```/0``
M````````````()\!```````"!```/@``````````````*)\!```````"!```
M/P``````````````,)\!```````"!```00``````````````.)\!```````"
M!```0@``````````````0)\!```````"!```0P``````````````2)\!````
M```"!```1```````````````4)\!```````"!```10``````````````6)\!
M```````"!```1@``````````````8)\!```````"!```1P``````````````
M:)\!```````"!```2```````````````<)\!```````"!```2@``````````
M````_7N_J?T#`)']>\&HP`-?UO![OZG0``"0$<Y&^1!B-I$@`A_6'R`#U1\@
M`]4?(`/5T```D!'21OD0@C:1(`(?UM```)`1UD;Y$*(VD2`"'];0``"0$=I&
M^1#"-I$@`A_6T```D!'>1OD0XC:1(`(?UM```)`1XD;Y$`(WD2`"'];0``"0
M$>9&^1`B-Y$@`A_6T```D!'J1OD00C>1(`(?UM```)`1[D;Y$&(WD2`"'];0
M``"0$?)&^1""-Y$@`A_6T```D!'V1OD0HC>1(`(?UM```)`1^D;Y$,(WD2`"
M'];0``"0$?Y&^1#B-Y$@`A_6T```D!$"1_D0`CB1(`(?UM```)`1!D?Y$"(X
MD2`"'];0``"0$0I'^1!".)$@`A_6T```D!$.1_D08CB1(`(?UM```)`1$D?Y
M$((XD2`"'];0``"0$19'^1"B.)$@`A_6T```D!$:1_D0PCB1(`(?UM```)`1
M'D?Y$.(XD2`"'];0``"0$2)'^1`".9$@`A_6T```D!$F1_D0(CF1(`(?UM``
M`)`1*D?Y$$(YD2`"'];0``"0$2Y'^1!B.9$@`A_6T```D!$R1_D0@CF1(`(?
MUM```)`1-D?Y$*(YD2`"'];0``"0$3I'^1#".9$@`A_6T```D!$^1_D0XCF1
M(`(?UM```)`10D?Y$`(ZD2`"'];0``"0$49'^1`B.I$@`A_6T```D!%*1_D0
M0CJ1(`(?UM```)`13D?Y$&(ZD2`"'];0``"0$5)'^1"".I$@`A_6T```D!%6
M1_D0HCJ1(`(?UM```)`16D?Y$,(ZD2`"'];0``"0$5Y'^1#B.I$@`A_6T```
MD!%B1_D0`CN1(`(?UM```)`19D?Y$"([D2`"'];0``"0$6I'^1!".Y$@`A_6
MT```D!%N1_D08CN1(`(?UM```)`1<D?Y$(([D2`"'];0``"0$79'^1"B.Y$@
M`A_6T```D!%Z1_D0PCN1(`(?UM```)`1?D?Y$.([D2`"'];0``"0$8)'^1`"
M/)$@`A_6T```D!&&1_D0(CR1(`(?UM```)`1BD?Y$$(\D2`"'];0``"0$8Y'
M^1!B/)$@`A_6T```D!&21_D0@CR1(`(?UM```)`1ED?Y$*(\D2`"'];0``"0
M$9I'^1#"/)$@`A_6T```D!&>1_D0XCR1(`(?UM```)`1HD?Y$`(]D2`"'];0
M``"0$:9'^1`B/9$@`A_6T```D!&J1_D00CV1(`(?UM```)`1KD?Y$&(]D2`"
M'];0``"0$;)'^1""/9$@`A_6T```D!&V1_D0HCV1(`(?UM```)`1ND?Y$,(]
MD2`"'];]>[NI_0,`D?-3`:G3``"PU```D/43`/GBAP.IXN,`D>$#`9'@3P"Y
MX#,!D97__Y?"``"0P```D$+\1_D`^$?YX0,"JC?__Y?```"0`,A'^0``0#F`
M`0`U9O__EV+"`I%`#`#Y8```M2``@%*1__^7J/__EX#>1_D``$"YQ?__EQ_<
M*#F4WD?Y@`)`N<'__Y<!*%(Y(0`?,@$H$CF``D"YO/__EP$H4CDA```R`2@2
M.>!/0+D4#``1`!``$0!\?9.,__^7Y"-`^>,#`*I@P@*1XD]`N0,$`/F``$#Y
M8```^0```/``0#.18`0`^<```+``.$#Y8`@`^0```/``3#.18`P`^0``@-(!
M$``1``0`D25\?9-AS"&+7P``:PP%`%1UP@*1/P``^>(#%"H$`(#2`0``L"$@
M&)&@#D#Y%?__E_0#`"J````UH`Y`^6'__Y?T`P`J=<("D:`.0/DY__^7````
M\`!\*Y&:``"48`$`M:`*0/F@``"U````\`!0*I&4``"4H`H`^6#"`I$`"$#Y
M0```M*X%`)1SP@*18`Y`^8C__Y>O_O^7X`,4*O-30:GU$T#Y_7O%J,`#7]:!
M>&#X86@E^-'__Q<=`(#2'@"`TN`#`)'!``"0(:`ND1_L?)(!```4X@,`JL0`
M`)##``"0P```D(3,1_D%`(#28]A'^0#`1_E!A$#X$O__%Q\@`]7```"P`.`!
MD<$``+`AX`&1/P``Z\```%3!``"0(=1'^6$``+3P`P&J``(?UL`#7];```"P
M`.`!D<$``+`AX`&1(0``RR+\?]-!#(&+(?Q!D\$``+3"``"00O!'^6(``+3P
M`P*J``(?UL`#7]8?(`/5_7N^J?T#`)'S"P#YTP``L&#B03D``@`UP```D`#H
M1_F```"TP```D```0/GY_O^7V/__EZ```/``T$?Y@```M"```-``X"61@O[_
MER``@%)@X@$Y\PM`^?U[PJC``U_6H```\`#L1_E``0"T_7N_J<$``)`@``#0
M_0,`D2$``I$`X"61Y_[_E_U[P:C-__\7S/__%_U[O*G]`P"1\U,!J?5;`JGW
M8P.I``4`M/8#`*J@``#P`.!'^1<`0/EW!`"T^`,!JN(#%JI``$`Y'_0`<008
M0'HA`P!40@`62_4#%ZI3?$"3M`)`^=0!`+3B`Q.JX0,6JN`#%*J"_O^7(`(`
M-8!J<S@?]`!QP0$`5+4"%\MS!@"1E`(3B[7^0Y,5`P"YX`,4JO-30:GU6T*I
M]V-#J?U[Q*C``U_60@0`D>/__Q>U(@"1Z/__%Q0`@-+U__\7_7N^J:$``/#]
M`P"1(>1'^2(`0/GB#P#Y`@"`TN%3`)')__^7H0``\"'D1_GB#T#Y(P!`^4(`
M`^L#`(#20```5/3^_Y?]>\*HP`-?UOU[O*G]`P"1\U,!J?,#`*J@``#PM```
M\/43`/D`Y$?Y]=,`D93B1_D!`$#YX1\`^0$`@-+A`Q6JX`,3JJ___Y<@`0"U
MH```\`#D1_GA'T#Y`@!`^2$``NL"`(#20`$`5-G^_Y>``D#YXC>`N0(,`HM`
M!$#Y0```^>#]_[1"(`"1_/__%_-30:GU$T#Y_7O$J,`#7];]>[*IH0``\/T#
M`)$AY$?Y\U,!J?5;`JGW8P.I^2,`^2(`0/GB;P#Y`@"`TH`"`+0!`$`Y]`,`
MJB$"`#39_?^7]@,`JL`!`+07``#0&```T/<N*9$8*RF1&0``T.`#%JH`_O^7
M\P,`JJ`!`+7@`Q:J)/[_E^`#%*I^_O^7H```\`#D1_GA;T#Y`@!`^2$``NL"
M`(#20`4`5*;^_Y=S3@"1X0,7JN`#$ZKJ_?^7@/W_-.$#&*K@`Q.JYOW_EP#]
M_S3@`Q2JE_[_E_4#`*K@`Q.JE/[_E[4"``NU"@`1H'Y`D_3]_Y?C`Q.JX@,4
MJO4#`*HA-RF1?_[_E^%C`9'@`Q6J;/[_EQ\$`#%``0!4X&M`N0`,%!(?$$!Q
MP0``5.`#%:JX__^7X`,5JE[^_Y?,__\7X`,5JMO]_Y?[__\7\U-!J?5;0JGW
M8T.I^2-`^?U[SJC``U_6_7NUJ:$``/#]`P"1(>1'^?,+`/GS`P"J(@!`^>)7
M`/D"`(#2X:,`D=W]_Y>``@`UX3M`N0(`E%(A#!02/Q!`<2000GK!``!4X`,3
MJD$`@%*/_?^7'P``<>`7GQJA``#P(>1'^>)70/DC`$#Y0@`#ZP,`@-*```!4
M6?[_EP``@%+W__\7\PM`^?U[RZC``U_6_7NZJ?T#`)'U6P*I]0,`JJ```/#S
M4P&I\P,!J@#D1_GW8P.I^2,`^0$`0/GA+P#Y`0"`TF`"0#D?]`!Q00``5',&
M`)'@`Q.J/?[_E^%3`9'V`P"JX`,5J@K__Y?T`P"J(`(`M#;^_Y??`@#KZ`0`
M5`$`@-)@:F$X@&HA."$$`)&@__\UH```\`#D1_GA+T#Y`@!`^2$``NL"`(#2
M0`D`5"O^_Y>T``#P@.)'^1D`0/D``(#2(B,`T?<#`"H`!`"107A@^*'__[7!
M``"0X`H`$2*P0+D`?'V3P@4`-.$#`*K@`QFJ/OW_EX'B1_D@``#YH/S_M)3B
M1_GA!@`1@`)`^1_8(?CW5P"YX0,5JB``0#D?]`!Q!!A`>B$%`%2T``#P]U>`
MN2$`%<O`"@"1E.)'^??R?=,`P"&+F`)`^63]_Y<`:S?X`/K_M.%7@+F``D#Y
M`7AA^.(#`:J@%D`X(00`D2#P'SA@```T'_0`<4'__U2@!X!20```.0``@-)B
M:F`X(F@@.``$`)&B__\UOO__%R(`@%(BL`"Y3?W_E_@#`*H@]_^TXGY]D^$#
M&:I,_?^7@.)'^1@``/G/__\7(00`D=/__Q?S4T&I]5M"J?=C0ZGY(T#Y_7O&
MJ,`#7];]>[^IH```\/T#`)$`W$?Y``!`N</]_Y?]>\&HH@``\",``-`!``#0
M0O1'^6-4(9$A3"F1L_W_%_U[OJG]`P"1\PL`^;,``/!SWD?Y8`)`N;3]_Y?K
M__^78`)`N;']_Y?S"T#Y!```T/U[PJB$/#.1XP,$J@4`@%("``"P`0``T$+@
M#9$AO"F1[OS_%PP*A-+_8RS+H```\/U[`*G]`P"1`.1'^?-3`:GTXP"1]1,`
M^0$`0/GA)Q#Y`0"`TO'\_Y?C`P`J!```T`(``-"$$"J10B`JD>`#%*HA`(+2
MU?S_EQ\$`#%!`0!4`P"`TJ```/``Y$?YX2=0^0(`0/DA``+K`@"`TB`%`%2:
M_?^7`7Q`DS\$0/%)``!4`'T@U&#^_S<`"(+2\V,@B^$#$ZK@`Q2J`@""TB_]
M_Y?T`P"J8/W_-P`$`!$`?$"3ZOS_E^,#`*K`_/^TE7Y`DQ\`$^N"``!4```5
MBW\"`.N#_?]4?P`3ZXD``%1@`A6+?P``Z^/\_U0@`()2GP(`:XS\_U3@`P.J
MX@,5JN$#$ZIJ_?^7XP,`JA]H-3C2__\7X`,#J@P*A-+]>T"I\U-!J?430/G_
M8RR+P`-?UK+__Q<,'(+2_V,LR_U[`*G]`P"1\U,!J?0#`*J@``#P]5L"J?,#
M`:H`Y$?Y]V,#J?EK!*D!`$#YX6\(^0$`@-(```#0`%`JD57^_Y?W`P"JX06`
M4N`#%*KA_/^7H`$`M````-#A`Q2J`'0JD?W^_Y>@``#P`.1'^>%O2/D"`$#Y
M(0`"ZP(`@-)@"0!42/W_E^`#%*I"_?^7%0``T/@#`"JAJBJ1X`,3JAD``-`:
M``#0)_W_ESDO*9'S`P"J6K,JD?9C`Y'S_/^T8`)`.1\``'%S$IF:5P$`M.$#
M$ZK@`Q>J>_S_E\```#6AJBJ1``"`TA?]_Y?S`P"J\___%^`#$ZHG_?^7`00`
M42-\0)-BRF$X7[P`<2`"`%0!!P`1(```"Q_\/W'L^?]4Y0,4JN0#&JKC`Q.J
MX`,6J@(``-`!`(+20O0MD4K\_Y<`!``1'P1`<:D``%0`?2#4X`,!*G]J(SCI
M__\7X6,!D>`#%JKP_/^7P/O_->!K0+D`#!02'R!`<4'[_U3@`Q:J(0"`4C3\
M_Y?`^O\UX0,6J@```-``="J1L/[_E^`#%JIY_/^7]`,`JK#__Q?@`Q2J#!R"
MTOU[0*GS4T&I]5M"J?=C0ZGY:T2I_V,LB\`#7];A`P"J(@!`.4(``#7``U_6
M(00`D5^\`'$`$(&:^O__%\`'`+3]>[ZI_0,`D?,+`/GS`P"J`0!`.<$``#4`
M``#0`"PID?,+0/G]>\*H6OS_%]W\_Y<"!`#18@("BW\"`NN"`P!40`!`.1^\
M`'&@`@!4?P("Z^("`%3@`P*J`?1?.#^\`'$A`@!40@0`T7\"`NN"``!40`!`
M.1^\`'%@__]40@`3RT`(`)$?!$#Q*`,`5$($`)%?!$#QR0$`5`!](-1"!`#1
MYO__%^(#`*KI__\7?P("ZZ']_U1@`D`Y'[P`<>#Z_U0```#0`+`JD=;__Q?#
M``"08T`#D>$#$ZK@`P.J6?S_E_,+0/G]>\*HP`-?U@``@-+\__\7````T``L
M*9'+__\7_7NZJ:```/#]`P"1`.1'^?-3`:D4``#0]5L"J18``-`3``#0`0!`
M^>$O`/D!`(#2(```T`!4(9$5``#0`"@`D;76*Y$"#$"IX@\#J0(,0:GB#P2I
M`$!`>>"C`'D```#0`+@JD:+]_Y<```#0`-PJD9_]_Y<```#0`/PJD9S]_Y<`
M``#0`"`KD9G]_Y>`/BN1E_W_EP```-``?"N1E/W_E\!2*I&2_?^78*XKD9#]
M_Y?@`Q6JCOW_EP```-``_"N1B_W_EP```-``="J1B/W_EP```-``)"R1<OW_
MEX```+3A`P"JX`,5JA_^_Y<```#0`&@LD6O]_Y?A`P"J@```M````-``E"B1
M%_[_EP```-``L"R18_W_E^$#`*K@`0"TP%(JD1#^_Y>`/BN1`0``T"%@+9$,
M_O^7H```\`#D1_GA+T#Y`@!`^2$``NL"`(#2(`(`5%?\_Y<```#0`/`LD5#]
M_Y?A`P"J8```M&"N*Y'M__\7`0``T.`'`9$A-"V10@&`TK/[_Y<`_?\UX2\!
MD??__Q?S4T&I]5M"J?U[QJC``U_6_7N^J?T#`)'S"P#YTP``D&`*0+D?!``Q
M00$`5````-``K"N1-OW_ET`!`+0``$`Y``$`-!_``''@!Y\:8`H`N6`*0+GS
M"T#Y_7O"J,`#7]8``(!2^O__%_U[OZG]`P"1+_S_E[[[_Y=```"T``!`^?U[
MP:C``U_6_7N]J?T#`)'U6P*I%0``T+9J+9'S4P&I\P,`JN`#%JH9_?^7@```
MM`$`0#GT`P"JX0``->$#$ZJ@:BV1\U-!J?5;0JG]>\.HP/W_%^$#$ZJ1^_^7
M@`(`M>`#$ZH*_/^7]0,`JN`#%*H'_/^7H`(`BP`(`)%H^_^7Y`,4JO4#`*KB
M`Q.J`P``T`$``-!CJ"J1(?0MD?#[_Y?A`Q6JX`,6JN?__Q?S4T&I]5M"J?U[
MPZC``U_6##*0TO]C+,OA(T"1_7L`J?T#`)'U6P*I]0,`JJ```/#S4P&I%@``
MT`#D1_GW8P.I^6L$J?LK`/D"`$#Y(L0`^0(`@-+```"0`"``D0*,0*GB#P:I
M`@Q"J>(/":D"#$.IX@\*J0(,1*GB#PNI`@Q%J>*/!ZD!#$#YX3L`^0`P0/G@
M1P#YP%(JD=+\_Y<``P"T`0!`.?,#`*JA`@`TK/__EZ```/#A(T"1`.1'^2+$
M0/D#`$#Y0@`#ZP,`@-)```!4R/O_E^`#$ZH,,I#2_7M`J?-30:GU6T*I]V-#
MJ?EK1*G[*T#Y_V,LBS;[_Q>0__^7\P,`J@`"`+7TXP&1@`)`^8```+43``#0
M<ZHMD0H``!2P_/^78```M90B`)'X__\7`0!`.:'__S0F^_^7\P,`JD#__[3@
M`Q.JIOO_EP#X?],7``#0``0`D??&+9$%^_^7^0,`JO0#`*IB`D`YH@D`-?1#
M`I&3`D#YDP$`M.`#$ZJ8_/^7\P,`JH`)`+0!`$`Y00D`-"#]_Y<`"0`TX`,3
MJ@S[_Y?S`P"J]X,!D;,``+7T`D#Y=```M(`"0#D@"``UX`,3JH?[_Y?W`P"J
MX`,9JH3[_Y?W`@`+]Q(0$1@``-#W?D"3X`,7JN+Z_Y?E`QFJ`[,JD>(#$ZH$
M``#0A-@MD?0#`*H!``#0(>PMD6G[_Y?@`Q2J`3B`4D[[_Y<?!``Q`08`5$?[
M_Y<$`$"YGT0`<8`%`%2@``#P`0``T*("0/GC`Q2J`,1'^2$0+I$``$#Y(/O_
MEQ,`@-*@``#PX2-`D0#D1_DBQ$#Y`P!`^4(``^L#`(#2X?+_5.`#$ZH,,I#2
M_7M`J?-30:GU6T*I]V-#J?EK1*G[*T#Y_V,LB\`#7];@`Q2JX0,7JG,&`)&4
M"@"10/O_EZW__Q>4(@"1KO__%^`#%*K4_/^7@```-.`#%*K`^O^7\P,`JO<B
M`)&T__\7X0,#D>`#%*JR^O^7^0,`*D`!`#2@``#0XP,4JJ("0/D!``"P`,1'
M^2'\+I$``$#Y\/K_E]#__Q?@TT"Y``P4$A\00'&!_O]4\]M`N37[_Y=_`@!K
M`?[_5.#30+D`(``2'P`'<8']_U3@`Q>JB?K_E_,#`*H```"P`)0MD2'\_Y=`
M"P"UMP)`^>`#%ZH=^_^7^@,`JA\,`'%M`P!4`'Q`DP$``+``$`#1(4@PD>`"
M`(M@^O^7@`(`-5\3`'&@``!46A<`4>#*>C@?O`!QP0$`5+4&0/F5`0"TX`,5
MJ@G[_Y<?#`#Q"0$`5``0`-$!``"PH`(`BR%<,)%.^O^7'P``<?<2E9K`_O^7
M(`T`->`#%ZH!`(!2>_K_E_4#`"J`#``T0@"`4B$"@)+W(P:1.?K_E^$#%ZK@
M`Q4JP@"`TKWZ_Y?@(T8Y(`8`->`G1CD?#`%QP04`5.`K1CD?!`%Q804`5.`O
M1CD?#`%Q`04`5.`S1CD?(`%QH00`5.`W1CD?%`%Q000`5$(`@%(A!X"2X`,5
M*B#Z_Y?A`Q>JX`,5*B(%@-*D^O^7!0``L.0#%ZJE/#.1`0``L`.S*I'B`Q2J
M(7`PD>`#$ZK#^O^7X`,4JJWZ_Y?A`Q.JP%(JD7O\_Y?@`Q.JI_[_EV7__Q>W
M`D#Y0?K_E^$#`*K@`Q>J7/W_E_<#`*I`]/^UH/__%P(`@%(!`(#2X`,5*O_Y
M_Y<:!0"4^0,`J@(`D-+A`Q>JX`,5*H'Z_Y?B`P"J'P``<2P#`%3@`Q4J]V,%
MD7/Z_Y?[`Q>JX0,9JAD``+`YQRV1%0"`TOH#!9'@`QJJ>@4`E$)K=3C@`Q>J
MX0,9JK4&`)'W"@"1E?K_E[]2`/$A__]4!0``L.0#&ZJE/#.1_P,&.<;__Q?A
M`Q>JX`,9J@X%`)3>__\7`0``L````+`A8"V1`*PKD1<``+#WYC"10/S_EQBS
M*I'5^?^7%0``L+4^,Y'D`P`JY0,5JN,#&*KB`Q2JX`,3J@$``+`AK#"1=_K_
ME^`#$ZH!.(!27/K_EQ\$`#$!]O]45?K_EP``0+D?1`!Q@?7_5,'Y_Y<Y!P`1
MY`,`*N8#%:KE`QDJXP,8JN(#%*KA`Q>JX`,3JF3Z_Y?M__\7_7N\J?T#`)'S
M4P&ILP``T/5;`JEUWD?Y]QL`^:`"0+E6^O^7]`,`JJ`"0+E3^O^7@<)".0'$
M`CD```"P`#PKD5[[_Y?```"T`0!`.3_$`'%A``!4``1`.4```#2O_?^7==Y'
M^:`"0+E$^O^78P"`4B(`@%(!``"P(2@QD=OY_Y?T`P"J(`(`M*`"0+D[^O^7
M@0I`^0(``+!",#&1(0!`^=KY_Y>`"D#Y``!`^0`,0+G``+`VH`)`N3#Z_Y>!
M"D#Y(0!`^9GY_Y=WWD?YM```\.`"0+DI^O^78P"`4B(`@%(!``"P(40QD<#Y
M_Y?U`P"J``,`M````+``="J1+_O_E_8#`*H``0"TX`)`N1OZ_Y>A"D#YX@,6
MJB$`0/F[^?^7#```%'#\_Y?V`P"JX`)`N?8$`+01^O^7H0I`^>(#%JHA`$#Y
ML?G_E^`#%JK[^?^7<]Y'^6`"0+D(^O^7]0,`JF`"0+D%^O^7(@"`4@$``+`A
M3#&1/?G_EP(``+#A`P"J0J`QD>`#%:J@^?^78`)`N9/"`I'Y^?^7'\0".0``
M`+``4"J1!?O_EV`*`/G``0"U8`9`^0W^_Y=@"@#Y0`$`M0```+``N#&1./G_
ME^OY_Y>!P@*1(@1`^:$*0/E"`$#YSO__%Y3"`I$!.(!2@`I`^<[Y_Y?C`P`J
M'T0`<2`!`%0`!``1'P0`<<D``%2`BD"I`0!`^0```+``/#*1(_G_E_-30:GU
M6T*I]QM`^?U[Q*C``U_6_7N^J?T#`)'S4P&I\P,`JO3\_Y?K_/^7]`,`JIO]
M_Y?``0`TLP$`M&`"0#E@`0`T`0``L.`#%*HAV"V15OG_EY\"`.NA``!4X`,3
MJO-30:G]>\*H!/O_%_-30:G]>\*HP`-?UO^#"M&A``#0!>``D0?@`9']>P"I
M_0,`D2'D1_DB`$#YXD\!^0(`@-+B8P"1Y@,"JJ$`0+G&0`"1I(1`^"$(P%K!
M`!_X@?Q@TR,<"%,AW'C3(1QPDF$``:J#_&C38QQXDF3@1*HA``2JP8`?^/\`
M!>L!_O]4`PB`4D0@0/EC!`!Q031`^4(@`)%%@%_X(0`$RD0$0/F$``7*(0`$
MRB3\7].!!`&J(7Q`DD$\`/EA_O]4!2!`J2HSC](&'$&I2E"K\@D00/FD_%O3
M`_U"TX04!:IC>`BJX0`&RJS\0M,A``B*C'D%JB$`!\J.?4"2)$`DB^&+0:DA
M``J+0@`*BX0``8MA?$"2*P`&RH0`"0MK`06*8P`,RFL!!LIC``2*:P$'BV,`
M`<IK`0*+@OQ;TT(4!*IC``:+:P$""^(70/E"``J+8P`"BV+]6]-"%`NJ8P`"
M"X+\0M-$>`2J@@$$RHU\0))"``N*0@`.RD(``8OA&T#Y(0`*BT(``8MA_%O3
M(10#JD(``0MA_4+3*W@+JH$`"\IL?4"2Y!]`^2$``XHA``W*A``*BR$`#HLA
M``2+1/Q;TX04`JHA``0+9/Q"TX-X`ZIK`0/*;GQ`DN0C0/EK`0**:P$,RH0`
M"HMK`0V+:P$$BR3\6].$%`&J:P$$"T3\0M.">`*J9``"RDU\0)+C)T#YA``!
MBH0`#LIC``J+A``,BX0``XMC_5O38Q0+JH0``PLC_$+387@!JD,``<HL?$"2
MXBM`^6,`"XIC``W*0@`*BV,`#HMC``*+@OQ;TT(4!*IC``(+8OU"TTMX"ZHB
M``O*;GU`DN$O0/E"``2*0@`,RB$`"HM"``V+0@`!BV'\6],A%`.J0@`!"X'\
M0M,D>`2J:P$$RHU\0)+A,T#Y:P$#BFL!#LHA``J+:P$,BVL!`8M!_%O3(10"
MJFL!`0MA_$+3(W@#JH$``\IL?$"2Y#=`^2$``HHA``W*A``*BR$`#HLA``2+
M9/U;TX04"ZHA``0+1/Q"TX)X`JID``+*3GQ`DN,[0/F$``N*A``,RF,`"HN$
M``V+A``#BR/\6]-C%`&JA``#"V/]0M-K>`NJ0P`+RFU]0)+B/T#Y8P`!BF,`
M#LI"``J+8P`,BV,``HN"_%O30A0$JF,``@LB_$+307@!JFL!`<HL?$"2XD-`
M^6L!!(IK`0W*0@`*BVL!#HMK`0*+8OQ;TT(4`ZIK`0(+@OQ"TT1X!*HB``3*
MCGQ`DN%'0/E"``.*0@`,RB$`"HM"``V+0@`!BV']6],A%`NJ0@`!"V'\0M,C
M>`.J@0`#RFU\0)+D2T#Y(0`+BB$`#LJ$``J+(0`,BR$`!(M$_%O3A!0"JB$`
M!`MD_4+3A'@+JFL`!,J,?$"2XT]`^6L!`HIK`0W*8P`*BVL!#HMK`0.+(_Q;
MTV,4`:IK`0,+0_Q"TV)X`JJ#``+*3WQ`DN130/EC``&*8P`,RF[]6].$``J+
M8P`-BV,`!(LD_$+3@7@!JLX5"ZI"``'*8P`."T(`"XHD?$"20@`/RFW\6]-"
M``R+K14#JNQ70/EN_$+3C`$*BT(`#(ML_4+3BWD+JE%`+8LA``O*H@$""R$`
M`XK#>0.J[%M`^2$`!,HA``^+3_Q;T^\5`JJ*`0J+3?Q"TR$`"HNM>0*J,$`O
MBV(`#<IJ`0/*0@`02DH!$4I*`02+2T`KB^2+2ZGA`0$++'2=TBS;K?(O_$+3
MA``,BT(`#(M*`02+)/Q;TX04`:IK`0*+X7D!JE%!)(N*``H+K@$!RD+]6]-$
M_4+30A0*JHIX"JK.`1%*<$$BBTL`"PLB``K*SD$CBT(`$$ID_4+334`MB^.+
M3*EC``R+0@`,B\X!`XMC_5O38Q0+JHMX"ZI/`0O*K0$"B]%!(XMC``X+[P$1
M2F+\6]-N_$+30A0#JN]!(8O#>0.JX;M-J;!!(HM"``T+9`$#RH0`$$I-_$+3
MA$`JBR$`#(O.`0R+[P$!BT'\6],A%`*JHGD"JFH``LJ$``Z+\4$ABR$`#PM*
M`1%*,/Q;TR_\0M,0%@&JX7D!JDI!*XM+``'*CD`PBP0"!`MK`0Y*8T$CBY#\
M6]/MKTZI$!8$JH[\0M/$>02JK0$,BVL!#(M*`0V++0`$RE%!,(L*`@H+K0$1
M2F,`"XNB02*+2_U;T^U_0/EK%0JJK0$,BV]`*XM"``V+3?U"TZIY"JIK`0,+
M@P`*RF,`#TIP_5O384`ABQ`6"ZKC@T#Y44`PBP("`@MC``R+(0`#BV/]0M-K
M>`NJ3_Q;TTX!"\KO%0*JS@$12LY!)(M$_$+3@G@"JC)`+XOCDU"IX0$!"VT!
M`LHO_%O3K0$22N\5`:JM02J+*OQ"TV,`#(M!>0&JS@$#BT,``<K102^+[@$.
M"V,`$4J$``R+:T`KB\_]6]/CCT#Y[Q4.JJT!!(MC``R+L$$OBVL!`XO#_4+3
M;G@.JNT!#0LD``[*A``02J_]6].$0"*+[Q4-JN*30/EQ02^+ZP$+"T(`#(N$
M``*+HOU"TTUX#:IO_5O3R@$-RN\5"ZI*`1%*2D$ABY!`+XOAET#YY`$$"R$`
M#(N/_%O32@$!BV']0M,A>`NJ[Q4$JJ,!`<IC`!!*44$OBV-`+HN._$+3Q'D$
MJNH!"@LB``3*0@`12D_]6]-"0"V+[Q4*JNLW4ZEK`0R+K0$,BV,`"XM"``V+
M<$`OB^,!`PM+_4+3;_Q;TVW\0M/O%0.J:GD*JJ-Y`ZJ+``K*44`OBTX!`\IK
M`1!*S@$12F%!(8O.022+ZQ-4J>(!`@M/_%O3[Q4"JFL!#(N$``R+(0`+B\X!
M!(LP0"^+X0$!"R3\6].$%`&JS@$$"T3\0M.">`*J:P`"RN2K0/EK`1!*:T$J
MBRK\0M-!>0&JC``,BVP!#(M+``&J+0`""FL!#HIM`0VJQ/U;TZU!(XN$%`ZJ
MXZ]`^8P!!`N+FY?2:^.Q\F,`"XNM`0.+@_U;TV,4#*JM`0,+P_U"TVYX#JHO
M``ZJQ`$!"N\!#(KD`02JA$`BB^*S0/E"``N+A``"BZ+]6]-"%`VJA``""X+]
M0M-,>`RJSP$,JHH!#@KO`0V*Z@$*JDI!(8OAMT#Y(0`+BTH!`8N!_%O3(10$
MJDH!`0NA_4+3+7@-JH\!#:JC`0P*X;M`^>\!!(KC`0.J(0`+BV-`+HMC``&+
M0?U;TR$4"JIC``$+@?Q"TR1X!*JN`02J@@`-"N&_0/G.`0J*P@$"JB$`"XM"
M0"R+0@`!BV'\6],A%`.J0@`!"T']0M,J>`JJC``*JD$!!`J,`0.*@0$!JNS#
M0/DA0"V+C`$+BR$`#(M,_%O3C!4"JB$`#`ML_$+3@WD#JDP!`ZIM``H*C`$"
MBHP!#:J$022+[,=`^8P!"XN$``R++/Q;TXP5`:J$``P+3/Q"TX)Y`JIL``*J
M30`#"HP!`8J,`0VJBD$JB^S+0/F,`0N+2@$,BXS\6].,%02J2@$,"RS\0M.!
M>0&J3``!JBT``@J,`02*C`$-JH-!(XOLST#YC`$+BV,`#(M,_5O3C!4*JF,`
M#`N,_$+3A'D$JBP`!*J-``$*C`$*BHP!#:J"02*+[--`^8P!"XM"``R+;/Q;
MTXP5`ZI"``P+3/U"TXIY"JJ,``JJ30$$"HP!`XJ,`0VJ@4$AB^S70/F,`0N+
M(0`,BTS\6].,%0*J(0`,"VS\0M.#>0.J3`$#JFT`"@J,`0**C`$-JH1!)(OL
MVT#YC`$+BX0`#(LL_%O3C!4!JH0`#`M,_$+3@GD"JFP``JI-``,*C`$!BHP!
M#:J*02J+[-]`^8P!"XM*`0R+C/Q;TXP5!*I*`0P++/Q"TX%Y`:I,``&J+0`"
M"HP!!(J,`0VJ@T$CB^SC0/F,`0N+8P`,BTS]6].,%0JJ8P`,"XS\0M.$>02J
M+``$JHT``0J,`0J*C`$-JH)!(HOLYT#YC`$+BT(`#(ML_%O3C!4#JD(`#`M,
M_4+3BGD*JHP`"JI-`00*C`$#BHP!#:J!02&+[.M`^8P!"XLA``R+3/Q;TXP5
M`JHA``P+;/Q"TX-Y`ZI,`0.J;0`*"HP!`HJ,`0VJA$$DB^SO0/F,`0N+A``,
MBRS\6].,%0&JA``,"TS\0M.">0*J;``"JDT``PJ,`0&*D/Q;TXP!#:H0%@2J
MBD$JB^SS0/F,`0N+2@$,BRS\0M.!>0&J2@$0"TP``:HM``(*C`$$BD_]6].,
M`0VJ[Q4*JH-!(XM0_4+3[/=`^8P!"XMC``R+;4`OB^\!`PN#_$+39'@$JN[]
M6],L``2J@P`!"HP!"HK.%0^JC`$#J@IZ"JKC^T#Y@D$BBVL`"XOC_4+30@`+
MB\LZF-),0"Z+S@$""X(`"LI+3+GR0@`-2LW]6]-!0"&+K14.JN+_0/EO>`^J
M0@`+BR$``HO"_4+3,D`MBZT!`0M!`0_*3G@.JB$`#$KP`0[*)$`DBZS]6]/A
M`T'Y$`(22HP5#:H00BJ+(0`+B^H'0?F$``&+D4`LBXP!!`M*`0N+H?U"TQ`"
M"HN*_5O3+7@-JDH5#*KD"T'YPP$-RAY"*HMC`!%*2@$0"X0`"XMO0"^+[P$$
MBU']6].$_4+3,18*JHQX#*I0_4+3XP]!^:(!#,H*>@JJ\D$QBT(`'DHO`@\+
M8P`+BX$!"LI.0"Z+(0`22LX!`XOC_5O38Q0/JBU`+8OA$T'YPD$CB^3]0M-C
M``X+CW@/JB$`"XNM`0&+1`$/RF'\6].$``)*(10#JHQ`+(OB%T'YL$$ABR$`
M#0MN_$+30@`+B\-Y`ZJ,`0*+(OQ;TT(4`:KN`0/*S@$02BW\0M.102*+RD$J
MBT(`#`NA>0&J[AM!^5#\6],0%@*J9``!RLX!"XM,_$+32@$.BX)Y`JI.03"+
M"@(*"^T?0?F$`!%*+``"RH1`+XM/_5O3K0$+B^\5"JJ,`0Y*3OU"TX0`#8O*
M>0JJD4`OBTT`"LKD`00+K0$12H-!(XNA02&+C_Q;T^TG0?GO%02J["-!^:T!
M"XLA``V+C?Q"TXP!"XND>02J8P`,BTP!!,IR0"^+XP$#"XP!$DJ"02*+;_Q;
MT^PK0?GO%0.JC`$+BS%`+XM"``R+;/Q"TX-Y`ZKA`0$+C@`#RLX!$4HO_%O3
MSD$JB^\5`:KJ+T'Y4$`OB^(!`@M*`0N+S@$*BRK\0M-!>0&J3_Q;TVT``<KO
M%0*JK0$02JU!)(O102^+Y#-!^>X!#@N$``N+S_U;TZT!!(M$_$+3@G@"JN\5
M#JHL``+*C`$12K!!+XN,02.+[0$-"^,W0?FO_5O3[Q4-JF,`"XN,`0.+P_U"
MTVYX#JJ102^+2@`.RNP!#`M*`1!*2D$ABX_]6]/A.T'Y[Q4,JB$`"XM*`0&+
MH?U"TRUX#:I002^+Q`$-RNH!"@N$`!%*C_U"TX1`(HOL>0RJXC]!^:,!#,IC
M`!!*3_U"TT(`"XMC0"Z+A``"BT+]6]-"%`JJZGD*JH$!"LJE0"R+D4`BBT(`
M!`OD0T'Y3OQ;T\X5`JHA`!%*A``+BR%`+8MC``2+1/Q"TW!`+HO#`0,+[D=!
M^8)X`JI-`0+*20$)"\X!"XNM`1!*(0`.BV[\6]/.%0.J0@`'"R$`#@L"I`&I
M)/Q;TX04`:HA``@+A``-B^U+0?FK`0N+90$%BX4`!0L%!`"I8?Q"TR%X`ZHF
M``8+!@@`^:```+``Y$?YX4]!^0(`0/DA``+K`@"`TD```%2H]?^7_7M`J?^#
M"I'``U_6_7N_J0`0@-+]`P"1`?7_EQ_\`JDB8(32HNBL\@(``/DB<972'W@`
MN:+YO?("!`#YPI^;TD(7L_(""`#YPHZ*TD(&HO("#`#Y`CZ<TD)ZN/("$`#Y
M_7O!J,`#7];]>[RI_0,`D?-3`:GS`P"J0'Q`D_5;`JGT`P"J8A9`^?<;`/E#
M#``+7P`#ZXD``%1B&D#Y0@0`D6(:`/EB&D#Y=>(`D4!T0(MC@@*I8'I`N8`#
M`#06"(!2U@(`2Y\"%FN@PB"+EM*6&L)^0),?``'KH@``5`,``HL_``/K0@``
M5`!](-0W``*+'P`!ZVD``%0?`!?K8___5%OU_Y=@>D"YP`(`"V!Z`+D?``%Q
MP0(`5.`#$ZJ4^_^7E`(62^$#%ZIWX@&1G_X`<8P"`%2"?D"3/P`5ZXD``%2@
M`@*+/P``ZP/]_U0_`!7K@@``5"```HN_`@#K8_S_5.`#%:I"]?^7='H`N?-3
M0:GU6T*I]QM`^?U[Q*C``U_6/P`5ZVD``%0_`!?KX_K_5#8``9&_`@'K:0``
M5+\"%NM#^O]4(@Q`J:(.`*F4`@%1(@Q!J:(.`:DB#$*IH@X"J2`$0ZF@!@.I
MX`,3JFC[_Y?A`Q:JUO__%_U[O*G]`P"1\U,!J?0#`*KS`P&J]5L"J37@`)'W
M&P#Y(!1`^38H0+DW,$"YX0^`$@`@`U/6"L!:`@0`$?<*P%JARB`XH,(BBU_@
M`'&-"0!4`0B`4B(``DL!`(!20GQ`DVWT_Y?@`Q.J2_O_EW_^`ZE__@2I?_X%
MJ7\V`/EW6@XIX`,3JD3[_Y=@`D#Y`/Q8TX`"`#E@`D#Y`/Q0TX`&`#E@`D#Y
M`/Q(TX`*`#E@`D#Y@`X`.6`&0/D`_%C3@!(`.6`&0/D`_%#3@!8`.6`&0/D`
M_$C3@!H`.6`&0/F`'@`Y8`I`^0#\6-.`(@`Y8`I`^0#\4-.`)@`Y8`I`^0#\
M2-.`*@`Y8`I`^8`N`#E@#D#Y`/Q8TX`R`#E@#D#Y`/Q0TX`V`#E@#D#Y`/Q(
MTX`Z`#E@#D#Y@#X`.6`20/D`_%C3@$(`.6`20/GU6T*I`/Q0TX!&`#E@$D#Y
M`/Q(TX!*`#E@$D#Y@$X`.>`#$ZKS4T&I]QM`^?U[Q*BO]/\7`0>`4B(``DL!
M`(!20GQ`DR+T_Y>[__\7_7N_J?T#`)']>\&HP`-?UB]T;7``4$%27U1-4$1)
M4@!414U01$E2`%1-4`!54T52`%5315).04U%`"XN`"5S+R5S`$1Y;F%,;V%D
M97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5`!E>&4`
M+W!R;V,O)6DO)7,`4$%27U1%35``4$%27U!23T=.04U%`#H`+P!015),-4Q)
M0@!015),3$E"`%!%4DPU3U!4`%!%4DQ)3P!005)?24Y)5$E!3$E:140`4$%2
M7U-005=.140`4$%27T-,14%.`%!!4E]$14)51P!005)?0T%#2$4`4$%27T=,
M3T)!3%]$14)51P!005)?1TQ/0D%,7U1-4$1)4@!005)?1TQ/0D%,7U1%35``
M4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`3$1?3$E"4D%265]0051(
M`%-94U1%30`E,#)X`'!A<BT`)7,E<R5S)7,`)7,Z(&-R96%T:6]N(&]F('!R
M:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`E<SH@
M<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M
M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*`'!A<FP`+G!A<@`E
M<R5S8V%C:&4M)7,E<P`E<R5S=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`
M&`!P97)L`#``4$%2.CI086-K97(Z.E9%4E-)3TX`,2XP-3(`56YA8FQE('1O
M(&-R96%T92!C86-H92!D:7)E8W1O<GD`)7,Z(&-R96%T:6]N(&]F('!R:79A
M=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`M
M90`M+0!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B
M?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA
M9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D<&%R7W1E;7`L("1P<F]G
M;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![(&EF("@D14Y6
M>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I
M;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@
M/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q
M6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I;F0Z
M.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D
M<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@
M)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E
M;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E
M;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,
M24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I;&5N86UE.PIP
M<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[
M(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G
M(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O
M;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W,#`L
M("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D978O;G5L;"`R
M/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K9W)O
M=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=*3L*
M?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN
M960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PHD4$%27TU!1TE#(#T@(EQN4$%2
M+G!M7&XB.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A
M)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@("`]
M/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@
M/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z
M("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G
M7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP
M*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L("1324=[
M7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N
M86UE(&]R(&QA<W0["FUY("1B=68["FUY("1S:7IE(#T@+7,@)'!R;V=N86UE
M.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&UA9VEC7W!O<SL*
M:68@*"1S:7IE(#P]("1C:'5N:U]S:7IE*2!["B1M86=I8U]P;W,@/2`P.PI]
M(&5L<VEF("@H;7D@)&T@/2`D<VEZ92`E("1C:'5N:U]S:7IE*2`^(#`I('L*
M)&UA9VEC7W!O<R`]("1S:7IE("T@)&T["GT@96QS92!["B1M86=I8U]P;W,@
M/2`D<VEZ92`M("1C:'5N:U]S:7IE.PI]"G=H:6QE("@D;6%G:6-?<&]S(#X]
M(#`I('L*<V5E:R!?1D@L("1M86=I8U]P;W,L(#`["G)E860@7T9(+"`D8G5F
M+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D
M:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PHD;6%G:6-?
M<&]S("L]("1I.PIL87-T.PI]"B1M86=I8U]P;W,@+3T@)&-H=6YK7W-I>F4[
M"GT*;&%S="!I9B`D;6%G:6-?<&]S(#P@,#L*<V5E:R!?1D@L("1M86=I8U]P
M;W,@+2`T+"`P.PIR96%D(%]&2"P@)&)U9BP@-#L*<V5E:R!?1D@L("1M86=I
M8U]P;W,@+2`T("T@=6YP86-K*").(BP@)&)U9BDL(#`["B1D871A7W!O<R`]
M('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@
M-#L@("`@("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE(&9I<G-T
M(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B
M=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@
M)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B)&9U
M;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA
M+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D
M97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@
M7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U
M9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L
M?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&-R8R1E
M>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L
M;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F
M:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@
M;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM
M>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&)A<V5N86UE)&5X="(L("1B=68L
M(#`W-34I.PIO=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*
M)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*)$UO9'5L94-A8VAE>R1F=6QL
M;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D
M9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.
M0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I
M9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2!D96QE=&4@
M)')E<75I<F5?;&ES='LD;6]D=6QE?2!O<B!R971U<FX["B1)3D-[)&UO9'5L
M97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,
M14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@
M24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B0V%N)W0@8W)E871E('1E
M;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*)&9H+3YP<FEN="@D:6YF
M;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E='5R;B`D9F@["GT*96QS
M92!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D:6YF;RT^>V-R8WTN<&TB
M+"`D:6YF;RT^>V)U9GTI.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&5N
M86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL96YA;64B.B`D(5T["G)E
M='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N)W0@
M9FEN9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO
M861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y
M.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I
M;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE
M<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I
M('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I
M;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M
M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER
M95]L:7-T>R1F:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<
M,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@("`@("`@
M("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D
M;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%
M3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A
M('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%2
M7T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP
M87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP
M("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?
M<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@
M86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.
M5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO
M<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!
M4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO
M(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@
M)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L
M<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L
M<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G
M8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2![
M"B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE
M="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^
M(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=
M.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS
M:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID
M96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!0
M05(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6
M.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]
M"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2![
M"GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E
M<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*
M;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ
M<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A
M<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI
M=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L
M("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%
M<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)65N=B`]
M(&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H
M)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A
M(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O
M;6<["GT*?3L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1P:"P@)SPZ
M<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@9FEL92`B)'!A
M<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L(#0["F1I92!Q<5LB
M)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F(&5Q(")02UPP
M,#-<,#`T(CL*8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I
M('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I
M+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U="(Z
M("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A
M9&5R.PII9B`H9&5F:6YE9"`D9&%T85]P;W,I('L*<F5A9"!?1D@L("1L;V%D
M97(L("1D871A7W!O<SL*?2!E;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*)&QO
M861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D
M;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL
M=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<
M)&QO861E<BP@)#`I.PI]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E
M;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V
M86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`](")?7T5.
M5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")005)?(B`N
M('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I8R@@*RE]
M>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H
M*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD["FEF("@D8G5N
M9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*
M;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@
M;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E
M>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]
M($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL
M97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O
M8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#
M;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X
M="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E
M9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F
M8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@
M)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I
M<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2![
M"B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME
M>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]
M("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@
M)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M
M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE
M<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*
M;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X
M=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=
M+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O
M;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB
M=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1F:"P@
M)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@
M)"%=.PHD8V]N=&5N="`](#PD9F@^.PIC;&]S92`D9F@["E!!4CHZ1FEL=&5R
M.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M
M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_
M.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W
M+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN
M="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN
M=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N
M=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD
M8V]N=&5N="D["F]U=',H<7%;5W)I='1E;B!A<R`B)&YA;64B72D["GT*?0HD
M>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["B1C86-H95]N
M86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*:68@*"$D8V%C:&5?
M;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["FUY("1C
M='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N(&UY("1F:"P@(CPZ<F%W
M(BP@)&]U=#L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92`D9F@["B1C86-H
M95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N86UE("X](")<
M,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C:&5?;F%M92`N
M/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C86-H95]N86UE*3L*)&9H+3YP<FEN
M="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B1F
M:"T^<')I;G0H)%!!4E]-04=)0RD["B1F:"T^8VQO<V4["F-H;6]D(#`W-34L
M("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P
M;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E
M<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O
M<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?
M1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C
M:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R
M8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D
M9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@
M9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G;F%M92)=
M.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H
M($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA
M;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;W5T<RAQ
M<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FEF("AD
M969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T
M:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S
M("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R
M7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E
M<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E
M<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>
M+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA
M;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT
M<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M
M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B
M)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E
M<W1?;F%M92)=*3L*?2!E;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M
M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(ETI.PHD;65M8F5R+3YE>'1R86-T
M5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L("1D97-T7VYA
M;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,
M:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6
M.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L
M92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;
M+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R
M;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@
M>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY
M("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF
M:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H
M.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[
M(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L
M97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E
M(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR
M97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V
M>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E
M<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ
M5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR
M97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/
M.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI
M=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E
M<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0
M871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I
M<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U
M:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5
M;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE
M9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E
M<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@
M7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N
M9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$[
M"G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@
M<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W
M*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D
M<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64[
M"FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@
M9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I
M("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H
M9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@
M>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\
M("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D
M:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@
M)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM0
M05)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY
M72D@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I92!Q
M<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["G-E96L@)&9H+"`M,3@L
M(#(["FUY("1B=68["G)E860@)&9H+"`D8G5F+"`V.PII9B`H)&)U9B!E<2`B
M7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@,CL*<F5A9"`D9F@L("1B=68L
M(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D
M96QI;7UC86-H92TD8G5F(CL*?0IE;'-E('L*;7D@)&1I9V5S="`](&5V86P*
M>PIR97%U:7)E($1I9V5S=#HZ4TA!.PIM>2`D8W1X(#T@1&EG97-T.CI32$$M
M/FYE=R@Q*3L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D
M:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PHD8W1X+3YA9&1F
M:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C='@M/FAE>&1I9V5S=#L*?2!\?"`D
M;71I;64["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TD9&EG
M97-T(CL*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!3GT@
M/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["GT*
M)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L(#`W
M-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@
M86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W-A=F5?87,@
M>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL
M;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M
M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;W!E;B!M>2`D
M9F@L("<^.G)A=R<L("1T96UP;F%M92!O<B!D:64@<7%;0V%N)W0@=W)I=&4@
M(B1T96UP;F%M92(Z("0A73L*<')I;G0@)&9H("1C;VYT96YT<SL*8VQO<V4@
M)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4[
M"G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP
M;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M
M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM0
M05)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD
M<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X
M*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE
M(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I
M9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R
M(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF
M("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US
M("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B1P
M<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H
M(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6
M>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D
M9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D
M96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL**"@D<')O
M9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T
M*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS
M=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!
M4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E
M;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R
M;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_
M($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@
M5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N
M86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#
M;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M
M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!
M3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])
M3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!
M3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@)$5.5GLG4$%2
M7R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I
M('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I
M9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R7V-L
M96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*:68@
M*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*
M96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM>2`D
M=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.
M(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?
M0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T
M.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92![
M"G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N
M9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O
M;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE
M>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]
M"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"90
M05(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7%;
M<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.
M;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA
M;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?
M5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T52
M4D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)2
M3U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I
M9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@!P97)L>'-I+F,`7U]%3E9?4$%2
M7T-,14%.7U\@("`@("`@("`@("`@("````````$;`SOP````'0```-R4__\(
M!0``[);__P@!```<E___'`$``%R7__\P`0``O)?__U0!``#PE___=`$``*R8
M__^H`0``^)C__\@!``",F?__\`$``.":__\H`@``<)O__TP"``!,G?__A`(`
M`(2=__^D`@``V)W__\@"```0G___^`(``!2?__\,`P``Z*#__U`#```(H?__
M9`,```RB__^@`P``L*/__\P#```(I/__\`,``"BD__\0!```W*3__T@$``#T
MJO__J`0``"BM___8!```C*W__S0%```LOO__6`4``(B^__]X!0``^+___ZP%
M```0``````````%Z4@`$>!X!&PP?`!`````8````W)7__S``````````$```
M`"P```#XE?__/``````````@````0````"26__]@`````$$.()T$G@-"DP)4
MWMW3#@`````<````9````&"6__\T`````$0.$)T"G@%'WMT.`````#````"$
M````=);__[P`````00Y`G0B>!T23!I0%E026`Y<"F`%C"M[=U]C5UM/4#@!!
M"P`<````N````/R6__],`````$$.()T$G@-1WMT.`````"0```#8````*)?_
M_Y0`````00Y`G0B>!T*3!I0%1)4$7=[=U=/4#@`T``````$``)27__]4`0``
M`$$.X`&=')X;1Y,:E!F5&)87EQ:8%9D4`DS>W=G7V-76T]0.`````"`````X
M`0``L)C__Y``````00ZP`9T6GA5$DQ1>WMW3#@```#0```!<`0``')G__]P!
M````00Y@G0R>"T*5")8'0Y,*E`E$EP:8!9D$`FS>W=G7V-76T]0.````'```
M`)0!``#`FO__.`````!!#A"=`IX!1M[=#@`````@````M`$``-B:__]4````
M`$$.()T$G@-"DP)*WMW3#@`````L````V`$```B;__\X`0```$(.T$!"G8H(
MGHD(0Y.(")2'"$*5A@@"1-W>U=/4#@`0````"`(``!"<__\$`````````$``
M```<`@```)S__]0!````0@[@(4&=G`2>FP1"DYH$E)D$1Y68!):7!)>6!)B5
M!)F4!)J3!`)HW=[9VM?8U=;3U`X`$````&`"``"0G?__(``````````X````
M=`(``)R=__\$`0```$(.()T$G@-"DP)'WMW3#@!!#B"3`IT$G@-O"M[=TPX`
M00M"#@#3W=X````H````L`(``&2>__^D`0```$$.8)T,G@M$DPJ4"4*5")8'
M`F'>W=76T]0.`"````#<`@``W)___U@`````00X@G02>`T*3`E`*WMW3#@!!
M"QP``````P``$*#__R``````00X0G0*>`4;>W0X`````-````"`#```0H/__
MM`````!!#C"=!IX%0I4"E@%#DP24`TP*WMW5UM/4#@!!"UG>W=76T]0.``!<
M````6`,``(R@__\8!@```$(.D(,"0IVR()ZQ($*5KB"6K2!(D[`@E*\@EZP@
MF*L@F:H@FJD@FZ@@;`K=WMO9VM?8U=;3U`X`00L":`K=WMO9VM?8U=;3U`X`
M00L````L````N`,``$2F__\T`@```$$.0)T(G@="DP:4!4*5!)8#0I<"`H7>
MW=?5UM/4#@`L````Z`,``$BH__]D`````$$.()T$G@-"DP*4`5(*WMW3U`X`
M00M"WMW3U`X````H````&`0``,R/___(`0```$$.4)T*G@E"DPB4!T.5!@)H
M"M[=U=/4#@!!"R````!$!```4*C__Z`0````00Z@!42=5)Y3`R($W=X.````
M`!P```!H!```S+C__UP`````00X0G0*>`57>W0X`````,````(@$```(N?__
M<`$```!!#D"=")X'0I,&E`5&E026`Y<"?`K>W=?5UM/4#@!!"P```#````"\
M!```1+K__Y0!````00Y`G0B>!T*3!I0%0Y4$E@-"EP("5@K>W=?5UM/4#@!!
M"P``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````$`@````````X!\````````!`````````/H"`````````0``````
M```%`P````````\`````````4P0````````,`````````(`9````````#0``
M```````02@```````!D`````````F)L!```````;``````````@`````````
M&@````````"@FP$``````!P`````````"`````````#U_O]O`````"`"````
M````!0````````#(#`````````8`````````"`,````````*`````````'$$
M````````"P`````````8`````````!4````````````````````#````````
M`(B=`0```````@````````"(!0```````!0`````````!P`````````7````
M`````/@3````````!P````````!`$0````````@`````````N`(````````)
M`````````!@`````````&````````````````````/O__V\``````0``"```
M``#Y__]O`````!``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````"0&0```````)`9````
M````D!D```````"0&0```````)`9````````D!D```````"0&0```````)`9
M````````D!D```````"0&0```````)`9````````D!D```````"0&0``````
M`)`9````````D!D```````"0&0```````)`9````````D!D```````"0&0``
M`````)`9````````D!D```````"0&0```````)`9````````D!D```````"0
M&0```````)`9````````D!D```````"0&0```````)`9````````D!D`````
M``"0&0```````)`9````````D!D```````"0&0```````)`9````````D!D`
M``````"0&0```````)`9````````D!D```````"0&0```````)`9````````
MD!D```````"0&0```````)`9````````D!D```````"0&0```````)`9````
M````D!D```````"0&0```````)`9````````D!D```````"0&0```````)`9
M````````D!D```````"0&0```````)`9````````D!D```````"0&0``````
M`)`9````````J)L!``````!@'0`````````````````````````````02@``
M``````````````````````````"`&0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````"@`0``````_____P`````@2@```````$M*````````````
M```````E2@```````"5+````````,$H````````W2P```````#A*````````
M```````````\2@```````$%*``````````````````#63````````$=#0SH@
M*$%L<&EN92`Q,"XS+C%?9VET,C`R,3`Y,C$I(#$P+C,N,2`R,#(Q,#DR,0``
M+G-H<W1R=&%B`"YI;G1E<G``+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N
M<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`
M+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R
M87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT````````````
M````````````````````````````````````````````````````````````
M``````````````````L````!`````@```````````@`````````"````````
M&@````````````````````$````````````````````3````]O__;P(`````
M````(`(````````@`@```````.@``````````P`````````(````````````
M````````'0````L````"``````````@#````````"`,```````#`"0``````
M``0````#````"``````````8`````````"4````#`````@````````#(#```
M`````,@,````````<00```````````````````$````````````````````M
M````!`````(`````````0!$```````!`$0```````+@"`````````P``````
M```(`````````!@`````````-P````0```!"`````````/@3````````^!,`
M``````"(!0````````,````1````"``````````8`````````$$````!````
M!@````````"`&0```````(`9````````$`````````````````````0`````
M```````````````\`````0````8`````````D!D```````"0&0```````-`#
M```````````````````0````````````````````1P````$````&````````
M`&`=````````8!T```````"P+```````````````````$```````````````
M`````$T````!````!@`````````02@```````!!*````````$```````````
M``````````0```````````````````!3`````0````(`````````($H`````
M```@2@```````&$^```````````````````!````````````````````6P``
M``$````"`````````(2(````````A(@```````#T````````````````````
M!````````````````````&D````!`````@````````!XB0```````'B)````
M````\`0```````````````````@```````````````````!S````#@````,`
M````````F)L!``````"8FP````````@````````````````````(````````
M``@`````````?P````\````#`````````*";`0``````H)L````````(````
M````````````````"``````````(`````````(L````&`````P````````"H
MFP$``````*B;````````X`$````````$``````````@`````````$```````
M``"4`````0````,`````````B)T!``````"(G0```````'@"````````````
M```````(``````````@`````````F0````$````#``````````"@`0``````
M`*````````!X````````````````````"````````````````````)\````(
M`````P````````!XH`$``````'B@````````6!````````````````````@`
M``````````````````"D`````0```#````````````````````!XH```````
M`#$````````````````````!``````````$``````````0````,`````````
M````````````````J:````````"M`````````````````````0``````````
'````````````
